@@ -152,7 +152,6 @@ public:
 
     string=new Lum::String();
     string->SetFlex(true,false);
-    string->RequestFocus();
     string->SetModel(search);
 
     vpanel->Add(string);
@@ -165,7 +164,6 @@ public:
     table=new Lum::Table();
     table->SetFlex(true,true);
     table->SetMinHeight(Lum::Base::Size::stdCharHeight,10);
-    table->RequestFocus();
     table->SetModel(currentPackages);
     table->SetHeaderModel(headerModel);
     table->SetSelection(selection);
@@ -191,7 +189,6 @@ public:
     vpanel->Add(new Lum::VSpace(true));
 
     button=new Lum::Button(L"_About");
-    button->RequestFocus();
     button->SetFlex(true,false);
     button->SetModel(aboutAction);
     vpanel->Add(button);
